AppPermissionManagerWeb class

A web implementation of the AppPermissionManagerPlatform of the AppPermissionManager plugin.

Inheritance

Constructors

AppPermissionManagerWeb()
Constructs a AppPermissionManagerWeb.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

check(AppPermissionManagerPermission permission) Future<AppPermissionManagerStatus>
override
checkMultiple(List<AppPermissionManagerPermission> permissions) Future<Map<AppPermissionManagerPermission, AppPermissionManagerStatus>>
override
getPlatformVersion() Future<String?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openAppSettings() Future<void>
override
request(AppPermissionManagerPermission permission) Future<AppPermissionManagerStatus>
override
requestMultiple(List<AppPermissionManagerPermission> permissions) Future<Map<AppPermissionManagerPermission, AppPermissionManagerStatus>>
override
statusStream(AppPermissionManagerPermission permission) Stream<AppPermissionManagerStatus>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void